==> breeze_website_builder_5.4.44.tar.gz: manage/upload_plugin.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 4/9/2013
//
	
	include ("check_session.php");
	
	$password = $_REQUEST['password'];
	
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Breeze Website Builder</title>

<link rel="stylesheet" href="manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#install_plugin_btn	{	width:80px;	}
#upload_plugin_login_btn	{
	width:100px;
	position:inherit;
}
</style>

<script language="javascript" src="js/hash.js" type="text/javascript"> </script>

<script language="javascript" type="text/javascript">
function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#install_plugin", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function SubmitLogin()
{
	var password = document.getElementById("password_input").value;
	var hash = Sha256.hash(password);
	document.getElementById("password").value = hash;
	document.getElementById("password_input").value = '';
	document.forms["formLogin"].submit();
}

function checkForEnter(e) {
	if (e.keyCode == 13) {
		SubmitLogin();
	}
}
</script>

</head>

<body <?php if (!$password) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
<?php
	if (!$password)
	{
?>
        <form action="upload_plugin.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
        <p class="title" align="center">Please enter the password for the "admin" user account:</p>
        <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
        <input type="hidden" name="password" id="password" />
        <p align="center">
        <table align="center" border="0"><tr><td>
        <div class='button_console' id="upload_plugin_login_btn" onClick="SubmitLogin();"><span class='button_console_text'>Login</span></div>
        </td></tr></table>
        </p>
        </form>
<?php
	}
	else
	{
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = 'admin'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		
		/////////////////////////////////////////////
		//Decrypt password for comparison:
		$enc_text = stripslashes($row["password"]);
		$key = stripslashes($row["UserID"]);
		
		//Convert key to codes and pad as necessary.
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			if ($i < strlen($key))
			{
				$c = $key{$i};
				$k[$i] = ord($c);
			}
			else
				$k[$i] = 65 + $i;
		}
		
		//Convert encrypted string to array of HEX uni-character codes.
		$j = 0;
		$q = 0;
		for( $i = 0; $i < strlen($enc_text); $i++)
		{
			if ($j == 0) {
				$c = $enc_text{$i};
				$j++;
			}
			else {
				$c = $c.$enc_text{$i};
				$e[$q] = hexdec($c);
				$q++;
				$j = 0;
			}
			
		}
		
		//Decrypt encrypted string with key to get original data.
		$decrypt_text = "";
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			$a[$i] = $e[$i] ^ $k[$i];
			$decrypt_text = $decrypt_text. chr($a[$i]);
		}
		////////////////////////////////////////////////////
		
		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
		$password_lookup = hash('sha256', $decrypt_text);
		if ($password_lookup == $password)
		{
?>

<table width="80%" align="center" border="0"><tr><td>
<div class="button_heading_sub_level_1" id="install_plugin_heading"><div class="button_heading_text_sub_level_1">Install Plugin</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
</td></tr></table>

<form name="frmUploadPlugin" id="frmUploadPlugin" action="install_plugin.php" method="post" enctype="multipart/form-data">
<table width="80%" align="center">
	<tr><td align="center"><h3>Select the plugin you want to install from your computer:</h3></td></tr>
	<tr><td align="center"><input name="plugin_file" id="plugin_file" type="file" /></td></tr>
    <tr><td align="center">
    <div class='button_console' id="install_plugin_btn" onClick="document.getElementById('frmUploadPlugin').submit();"><span class='button_console_text'>Install</span></div>
    </td></tr>
</table>
</form>

<?php
		}
		else
			echo "Your password has not been confirmed.   Click <a href='upload_plugin.php'> here </a> to re-enter your password.";
	}
?>

</body>
</html>

==> breeze_website_builder_5.4.54.tar.gz: manage/upload_plugin.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 4/9/2013
//
	
	include ("check_session.php");
	
	$password = $_REQUEST['password'];
	
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Breeze Website Builder</title>

<link rel="stylesheet" href="manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	position:relative;
	display:block;
	top:-15px;
	left:215px;
	height:31px;
	width:31px;
	z-index:100;
}
#install_plugin_btn	{	width:80px;	}
#upload_plugin_login_btn	{
	width:100px;
	position:inherit;
}
</style>

<script language="javascript" src="js/hash.js" type="text/javascript"> </script>

<script language="javascript" type="text/javascript">
function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#install_plugin", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}

function SubmitLogin()
{
	var password = document.getElementById("password_input").value;
	var hash = Sha256.hash(password);
	document.getElementById("password").value = hash;
	document.getElementById("password_input").value = '';
	document.forms["formLogin"].submit();
}

function checkForEnter(e) {
	if (e.keyCode == 13) {
		SubmitLogin();
	}
}
</script>

</head>

<body <?php if (!$password) { ?>onLoad="document.getElementById('password_input').focus();"<?php } ?>>
<?php
	if (!$password)
	{
?>
        <form action="upload_plugin.php" method="post" enctype="multipart/form-data" name="formLogin" id="formLogin">
        <p class="title" align="center">Please enter the password for the "admin" user account:</p>
        <p align="center"><input name="password_input" id="password_input" type="password" onKeyDown="checkForEnter(event);" /></p>
        <input type="hidden" name="password" id="password" />
        <p align="center">
        <table align="center" border="0"><tr><td>
        <div class='button_console' id="upload_plugin_login_btn" onClick="SubmitLogin();"><span class='button_console_text'>Login</span></div>
        </td></tr></table>
        </p>
        </form>
<?php
	}
	else
	{
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = 'admin'";
		$result = $bwb_dbh->query($query);
		$row = $result->fetch(PDO::FETCH_ASSOC);
		
		/////////////////////////////////////////////
		//Decrypt password for comparison:
		$enc_text = stripslashes($row["password"]);
		$key = stripslashes($row["UserID"]);
		
		//Convert key to codes and pad as necessary.
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			if ($i < strlen($key))
			{
				$c = $key{$i};
				$k[$i] = ord($c);
			}
			else
				$k[$i] = 65 + $i;
		}
		
		//Convert encrypted string to array of HEX uni-character codes.
		$j = 0;
		$q = 0;
		for( $i = 0; $i < strlen($enc_text); $i++)
		{
			if ($j == 0) {
				$c = $enc_text{$i};
				$j++;
			}
			else {
				$c = $c.$enc_text{$i};
				$e[$q] = hexdec($c);
				$q++;
				$j = 0;
			}
			
		}
		
		//Decrypt encrypted string with key to get original data.
		$decrypt_text = "";
		for( $i = 0; $i < (strlen($enc_text))/2; $i++)
		{
			$a[$i] = $e[$i] ^ $k[$i];
			$decrypt_text = $decrypt_text. chr($a[$i]);
		}
		////////////////////////////////////////////////////
		
		$decrypt_text = str_replace(BWB_SALT, '', $decrypt_text);
		$password_lookup = hash('sha256', $decrypt_text);
		if ($password_lookup == $password)
		{
?>

<table width="80%" align="center" border="0"><tr><td>
<div class="button_heading_sub_level_1" id="install_plugin_heading"><div class="button_heading_text_sub_level_1">Install Plugin</div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
</td></tr></table>

<form name="frmUploadPlugin" id="frmUploadPlugin" action="install_plugin.php" method="post" enctype="multipart/form-data">
<table width="80%" align="center">
	<tr><td align="center"><h3>Select the plugin you want to install from your computer:</h3></td></tr>
	<tr><td align="center"><input name="plugin_file" id="plugin_file" type="file" /></td></tr>
    <tr><td align="center">
    <div class='button_console' id="install_plugin_btn" onClick="document.getElementById('uploading_gif').style.display = 'inline'; document.getElementById('frmUploadPlugin').submit();"><span class='button_console_text'>Install</span></div>
    </td></tr>
    <tr><td align="center"><img src="images/uploading.gif" alt="Uploading..." id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
</table>
</form>

<?php
		}
		else
			echo "Your password has not been confirmed.   Click <a href='upload_plugin.php'> here </a> to re-enter your password.";
	}
?>

</body>
</html>
